==> ucam-identitylib-1.0.2.tar.gz: ucam-identitylib-1.0.2/identitylib/card_client/models/__init__.py <==
# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from identitylib.card_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from identitylib.card_client.model.api_exception import APIException
from identitylib.card_client.model.available_barcode import AvailableBarcode
from identitylib.card_client.model.card import Card
from identitylib.card_client.model.card_identifier import CardIdentifier
from identitylib.card_client.model.card_logo import CardLogo
from identitylib.card_client.model.card_note import CardNote
from identitylib.card_client.model.card_request import CardRequest
from identitylib.card_client.model.card_request_distinct_values import CardRequestDistinctValues
from identitylib.card_client.model.card_request_summary import CardRequestSummary
from identitylib.card_client.model.card_summary import CardSummary
from identitylib.card_client.model.inline_object import InlineObject
from identitylib.card_client.model.inline_object1 import InlineObject1
from identitylib.card_client.model.inline_object2 import InlineObject2
from identitylib.card_client.model.inline_response200 import InlineResponse200
from identitylib.card_client.model.inline_response2001 import InlineResponse2001
from identitylib.card_client.model.inline_response2002 import InlineResponse2002
from identitylib.card_client.model.inline_response2003 import InlineResponse2003
from identitylib.card_client.model.inline_response2004 import InlineResponse2004
from identitylib.card_client.model.inline_response2005 import InlineResponse2005
from identitylib.card_client.model.inline_response2006 import InlineResponse2006
from identitylib.card_client.model.inline_response2006_details import InlineResponse2006Details
from identitylib.card_client.model.inline_response2007 import InlineResponse2007
from identitylib.card_client.model.inline_response2008 import InlineResponse2008
from identitylib.card_client.model.inline_response2008_results import InlineResponse2008Results
from identitylib.card_client.model.v1beta1_card_requests_update_identifiers import V1beta1CardRequestsUpdateIdentifiers
from identitylib.card_client.model.v1beta1_card_requests_update_updates import V1beta1CardRequestsUpdateUpdates
from identitylib.card_client.model.validation_error import ValidationError

==> ucam-identitylib-1.0.5.tar.gz: ucam-identitylib-1.0.5/identitylib/card_client/models/__init__.py <==
# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from identitylib.card_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from identitylib.card_client.model.api_exception import APIException
from identitylib.card_client.model.available_barcode import AvailableBarcode
from identitylib.card_client.model.card import Card
from identitylib.card_client.model.card_identifier import CardIdentifier
from identitylib.card_client.model.card_logo import CardLogo
from identitylib.card_client.model.card_note import CardNote
from identitylib.card_client.model.card_request import CardRequest
from identitylib.card_client.model.card_request_distinct_values import CardRequestDistinctValues
from identitylib.card_client.model.card_request_summary import CardRequestSummary
from identitylib.card_client.model.card_summary import CardSummary
from identitylib.card_client.model.inline_object import InlineObject
from identitylib.card_client.model.inline_object1 import InlineObject1
from identitylib.card_client.model.inline_object2 import InlineObject2
from identitylib.card_client.model.inline_response200 import InlineResponse200
from identitylib.card_client.model.inline_response2001 import InlineResponse2001
from identitylib.card_client.model.inline_response2002 import InlineResponse2002
from identitylib.card_client.model.inline_response2003 import InlineResponse2003
from identitylib.card_client.model.inline_response2004 import InlineResponse2004
from identitylib.card_client.model.inline_response2005 import InlineResponse2005
from identitylib.card_client.model.inline_response2006 import InlineResponse2006
from identitylib.card_client.model.inline_response2006_details import InlineResponse2006Details
from identitylib.card_client.model.inline_response2007 import InlineResponse2007
from identitylib.card_client.model.inline_response2008 import InlineResponse2008
from identitylib.card_client.model.inline_response2008_results import InlineResponse2008Results
from identitylib.card_client.model.v1beta1_card_requests_update_fields import V1beta1CardRequestsUpdateFields
from identitylib.card_client.model.v1beta1_card_requests_update_identifiers import V1beta1CardRequestsUpdateIdentifiers
from identitylib.card_client.model.v1beta1_card_requests_update_updates import V1beta1CardRequestsUpdateUpdates
from identitylib.card_client.model.validation_error import ValidationError
